==> BenchExec-1.7.tar.gz: BenchExec-1.7/benchexec/tools/ultimateautomizer.py <==
"""
BenchExec is a framework for reliable benchmarking.
This file is part of BenchExec.

Copyright (C) 2015  Daniel Dietsch
All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from . import ultimate

class Tool(ultimate.UltimateTool):

    REQUIRED_PATHS = [
                  "artifacts.xml",
                  "AutomizerTermination.xml",
                  "Automizer.xml",
                  "AutomizerWitnessValidation.xml",
                  "configuration",
                  "features",
                  "Kojak.xml",
                  "p2",
                  "plugins",
                  "svcomp-Deref-32bit-Automizer_Bitvector.epf",
                  "svcomp-Deref-32bit-Automizer_Default.epf",
                  "svcomp-DerefFreeMemtrack-32bit-Automizer_Bitvector.epf",
                  "svcomp-DerefFreeMemtrack-32bit-Automizer_Default.epf",
                  "svcomp-Overflow-64bit-Automizer_Default.epf",
                  "svcomp-Reach-32bit-Automizer_Bitvector.epf",
                  "svcomp-Reach-32bit-Automizer_Default.epf",
                  "svcomp-Reach-64bit-Automizer_Bitvector.epf",
                  "svcomp-Reach-64bit-Automizer_Default.epf",
                  "svcomp-Termination-64bit-Automizer_Default.epf",
                  "Ultimate",
                  "Ultimate.ini",
                  "Ultimate.py",
                  "z3"
                  ]

    def name(self):
        return 'ULTIMATE Automizer'

==> BenchExec-1.16.tar.gz: BenchExec-1.16/benchexec/tools/ultimateautomizer.py <==
"""
BenchExec is a framework for reliable benchmarking.
This file is part of BenchExec.

Copyright (C) 2015  Daniel Dietsch
All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from . import ultimate

class Tool(ultimate.UltimateTool):

    REQUIRED_PATHS_SVCOMP17 = [
                  "artifacts.xml",
                  "AutomizerTermination.xml",
                  "AutomizerWitnessValidation.xml",
                  "AutomizerReach.xml",
                  "AutomizerMemDerefMemtrack.xml",
                  "configuration",
                  "cvc4",
                  "features",
                  "LICENSE",
                  "LICENSE.GPL",
                  "LICENSE.GPL.LESSER",
                  "p2",
                  "plugins",
                  "README",
                  "svcomp-DerefFreeMemtrack-32bit-Automizer_Bitvector.epf",
                  "svcomp-DerefFreeMemtrack-32bit-Automizer_Default.epf",
                  "svcomp-DerefFreeMemtrack-64bit-Automizer_Bitvector.epf",
                  "svcomp-DerefFreeMemtrack-64bit-Automizer_Default.epf",
                  "svcomp-Overflow-32bit-Automizer_Default.epf",
                  "svcomp-Overflow-64bit-Automizer_Default.epf",
                  "svcomp-Reach-32bit-Automizer_Bitvector.epf",
                  "svcomp-Reach-32bit-Automizer_Default.epf",
                  "svcomp-Reach-64bit-Automizer_Bitvector.epf",
                  "svcomp-Reach-64bit-Automizer_Default.epf",
                  "svcomp-Termination-32bit-Automizer_Default.epf",
                  "svcomp-Termination-64bit-Automizer_Default.epf",
                  "Ultimate",
                  "Ultimate.ini",
                  "Ultimate.py",
                  "z3",
                  "mathsat"
                  ]

    def name(self):
        return 'ULTIMATE Automizer'
